@@ -41,7 +41,7 @@ def get_data_from_response(server_response, capture_headers=True):
     if capture_headers and server_response.headers:
         data["headers"] = {
             key: ";".join(server_response.headers.getall(key))
-            for key in compat.iterkeys(server_response.headers)
+            for key in server_response.headers.keys()
         }
     return data
 
